Module: Google::Cloud::OracleDatabase
- Defined in:
- lib/google/cloud/oracle_database.rb,
lib/google/cloud/oracle_database/version.rb
Constant Summary collapse
- VERSION =
"0.1.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.oracle_database| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-oracle_database library.
-
.oracle_database(version: :v1, &block) ⇒ ::Object
Create a new client object for OracleDatabase.
Class Method Details
.configure {|::Google::Cloud.configure.oracle_database| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-oracle_database library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
103 104 105 106 107 |
# File 'lib/google/cloud/oracle_database.rb', line 103 def self.configure yield ::Google::Cloud.configure.oracle_database if block_given? ::Google::Cloud.configure.oracle_database end |
.oracle_database(version: :v1, &block) ⇒ ::Object
Create a new client object for OracleDatabase.
By default, this returns an instance of
Google::Cloud::OracleDatabase::V1::OracleDatabase::Rest::Client
for a REST client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the OracleDatabase service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About OracleDatabase
Service describing handlers for resources
66 67 68 69 70 71 72 73 74 75 |
# File 'lib/google/cloud/oracle_database.rb', line 66 def self.oracle_database version: :v1, &block require "google/cloud/oracle_database/#{version.to_s.downcase}" package_name = Google::Cloud::OracleDatabase .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::OracleDatabase.const_get(package_name).const_get(:OracleDatabase) service_module.const_get(:Rest).const_get(:Client).new(&block) end |